vintage_net v0.6.0 VintageNet.IP.DhcpdConfig View Source
This is a helper module for VintageNet.Technology implementations that use a DHCP server.
DHCP server parameters are:
start- Start of the lease blockend- End of the lease blockmax_leases- The maximum number of leasesdecline_time- The amount of time that an IP will be reserved (leased to nobody)conflict_time-The amount of time that an IP will be reservedoffer_time- How long an offered address is reserved (seconds)min_lease- If client asks for lease below this value, it will be rounded up to this value (seconds)auto_time- The time period at which udhcpd will write out leases file.static_leases- list of{mac_address, ip_address}
Link to this section Summary
Functions
Add udhcpd configuration commands for running a DHCP server
Normalize the DHCPD parameters in a configuration.
Link to this section Functions
Link to this function
add_config(raw_config, arg2, opts)
View Sourceadd_config(VintageNet.Interface.RawConfig.t(), map(), keyword()) :: VintageNet.Interface.RawConfig.t()
Add udhcpd configuration commands for running a DHCP server
Normalize the DHCPD parameters in a configuration.