VintageNet.InterfacesMonitor (vintage_net v0.13.9)

Copy Markdown View Source

Monitor available interfaces

Currently this works by polling the system for what interfaces are visible. They may or may not be configured.

Summary

Functions

Returns a specification to start this module under a supervisor.

Force clear all addresses

Functions

child_spec(init_arg)

Returns a specification to start this module under a supervisor.

See Supervisor.

force_clear_ipv4_addresses(ifname)

@spec force_clear_ipv4_addresses(VintageNet.ifname()) :: :ok

Force clear all addresses

This is useful to notify everyone that an address should not be used immediately. This can be used to fix a race condition where the blip for an address going away to coming back isn't reported.

start_link(args)

@spec start_link(any()) :: GenServer.on_start()