VintageNet.Route.InterfaceInfo (vintage_net v0.11.0) View Source
Routing information for an interface
Link to this section Summary
Link to this section Types
Specs
t() :: %VintageNet.Route.InterfaceInfo{
default_gateway: :inet.ip_address() | nil,
interface_type: VintageNet.interface_type(),
ip_subnets: [{:inet.ip_address(), VintageNet.prefix_length()}],
status: VintageNet.connection_status(),
weight: weight()
}
Routing information
:default_gateway- default gateway IP address ornilif there isn't one:ip_subnets- zero or more IP addresses and prefix lengths for what's on this LAN:weight- a value to pass on when calculating the routing table metric for weighting an interface over another one:interface_type- a rough categorization of the interface between:ethernet,:wifi,:cellular, etc. based on the name. SeeVintageNet.Interface.NameUtilities.:status- whether the interface is:disconnected,:lan, or:internet
Specs
weight() :: 0..9
A weight that can be used to differentiate two interfaces that would otherwise be the same priority
Lower weights are higher priority.